@@ -22,6 +22,7 @@
 
 #include "forwardingmodel.h"
 
+#include <QQmlParserStatus>
 #include <QSortFilterProxyModel>
 
 class GroupSortProxy : public QSortFilterProxyModel
@@ -52,14 +53,21 @@ class InvalidAppsFilterProxy : public QSortFilterProxyModel
         QPointer<AbstractModel> m_parentModel;
 };
 
-class RecentUsageModel : public ForwardingModel
+class RecentUsageModel : public ForwardingModel, public QQmlParserStatus
 {
     Q_OBJECT
+    Q_INTERFACES(QQmlParserStatus)
+
+    Q_PROPERTY(int ordering READ ordering WRITE setOrdering NOTIFY orderingChanged)
 
     public:
         enum IncludeUsage { AppsAndDocs, OnlyApps, OnlyDocs };
+        enum Ordering { Recent, Popular };
 
-        explicit RecentUsageModel(QObject *parent = 0, IncludeUsage usage = AppsAndDocs);
+        explicit RecentUsageModel(
+                QObject *parent = 0,
+                IncludeUsage usage = AppsAndDocs,
+                int ordering = Recent);
         ~RecentUsageModel();
 
         QString description() const;
@@ -73,6 +81,15 @@ class RecentUsageModel : public ForwardingModel
 
         IncludeUsage usage() const;
 
+        void setOrdering(int ordering);
+        int ordering() const;
+
+        void classBegin() override;
+        void componentComplete() override;
+
+    Q_SIGNALS:
+        void orderingChanged(int ordering);
+
     private Q_SLOTS:
         void refresh();
 
@@ -86,6 +103,10 @@ class RecentUsageModel : public ForwardingModel
 
         IncludeUsage m_usage;
         QPointer<QAbstractItemModel> m_activitiesModel;
+
+        Ordering m_ordering;
+
+        bool m_complete;
 };
 
 #endif
