@@ -20,27 +20,27 @@
 #ifndef _KCM_SEARCH_H
 #define _KCM_SEARCH_H
 
-#include <KCModule>
 #include <KConfig>
 #include <KConfigGroup>
 
 #include <Plasma/Package>
+#include <KQuickAddons/ConfigModule>
 
-class QQuickView;
 class QStandardItemModel;
 
-class KCMSplashScreen : public KCModule
+class KCMSplashScreen : public KQuickAddons::ConfigModule
 {
     Q_OBJECT
     Q_PROPERTY(QStandardItemModel *splashModel READ splashModel CONSTANT)
     Q_PROPERTY(QString selectedPlugin READ selectedPlugin WRITE setSelectedPlugin NOTIFY selectedPluginChanged)
+    Q_PROPERTY(int selectedPluginIndex READ selectedPluginIndex NOTIFY selectedPluginIndexChanged)
 
 public:
     enum Roles {
         PluginNameRole = Qt::UserRole +1,
         ScreenhotRole
     };
-    KCMSplashScreen(QWidget* parent, const QVariantList& args);
+    KCMSplashScreen(QObject* parent, const QVariantList& args);
 
     QList<Plasma::Package> availablePackages(const QString &component);
 
@@ -49,6 +49,8 @@ public:
     QString selectedPlugin() const;
     void setSelectedPlugin(const QString &plugin);
 
+    int selectedPluginIndex() const;
+
 public Q_SLOTS:
     void load();
     void save();
@@ -57,9 +59,9 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void selectedPluginChanged();
+    void selectedPluginIndexChanged();
 
 private:
-    QQuickView *m_quickView;
     QStandardItemModel *m_model;
     Plasma::Package m_package;
     QString m_selectedPlugin;
