@@ -38,6 +38,7 @@ class KCMLookandFeel : public KQuickAddons::ConfigModule
     Q_OBJECT
     Q_PROPERTY(QStandardItemModel *lookAndFeelModel READ lookAndFeelModel CONSTANT)
     Q_PROPERTY(QString selectedPlugin READ selectedPlugin WRITE setSelectedPlugin NOTIFY selectedPluginChanged)
+    Q_PROPERTY(int selectedPluginIndex READ selectedPluginIndex NOTIFY selectedPluginIndexChanged)
 
     Q_PROPERTY(bool applyColors READ applyColors WRITE setApplyColors NOTIFY applyColorsChanged)
     Q_PROPERTY(bool applyWidgetStyle READ applyWidgetStyle WRITE setApplyWidgetStyle NOTIFY applyWidgetStyleChanged)
@@ -74,6 +75,8 @@ public:
     QString selectedPlugin() const;
     void setSelectedPlugin(const QString &plugin);
 
+    int selectedPluginIndex() const;
+
     //Setters of the various theme pieces
     void setWidgetStyle(const QString &style);
     void setColors(const QString &scheme, const QString &colorFile);
@@ -84,6 +87,7 @@ public:
     void setLockScreen(const QString &theme);
     void setWindowSwitcher(const QString &theme);
     void setDesktopSwitcher(const QString &theme);
+    void setWindowDecoration(const QString &library, const QString &theme);
 
     void setApplyColors(bool apply);
     bool applyColors() const;
@@ -117,6 +121,7 @@ Q_SIGNALS:
     void applyWindowSwitcherChanged();
     void applyDesktopSwitcherChanged();
     void resetDefaultLayoutChanged();
+    void selectedPluginIndexChanged();
 
 private:
     QDir cursorThemeDir(const QString &theme, const int depth);
@@ -138,6 +143,7 @@ private:
     bool m_applyWindowSwitcher : 1;
     bool m_applyDesktopSwitcher : 1;
     bool m_resetDefaultLayout : 1;
+    bool m_applyWindowDecoration : 1;
 };
 
 #endif
